==> haskell-unix-compat-0.5.2-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unix-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 unix-compat
version:              0.5.2
visibility:           public
id:                   unix-compat-0.5.2-1FQI6nqgJsoGP4VQqT0w3a
key:                  unix-compat-0.5.2-1FQI6nqgJsoGP4VQqT0w3a
license:              BSD-3-Clause
maintainer:           Jacob Stanley <jacob@stanley.io>
author:
    Björn Bringert, Duncan Coutts, Jacob Stanley, Bryan O'\''Sullivan

homepage:             http://github.com/jacobstanley/unix-compat
synopsis:             Portable POSIX-compatibility layer.
description:
    This package provides portable implementations of parts
    of the unix package. This package re-exports the unix
    package when available. When it isn'\''t available,
    portable implementations are used.

category:             System
abi:                  de043b1f88c4b79cc78259cf63902e20
exposed:              True
exposed-modules:
    System.PosixCompat System.PosixCompat.Extensions
    System.PosixCompat.Files System.PosixCompat.Temp
    System.PosixCompat.Time System.PosixCompat.Types
    System.PosixCompat.Unistd System.PosixCompat.User

import-dirs:          /usr/lib/ghc-8.8.3/site-local/unix-compat-0.5.2
library-dirs:         /usr/lib/ghc-8.8.3/site-local/unix-compat-0.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/unix-compat-0.5.2
hs-libraries:         HSunix-compat-0.5.2-1FQI6nqgJsoGP4VQqT0w3a
include-dirs:         /usr/lib/ghc-8.8.3/site-local/unix-compat-0.5.2/include
includes:             HsUnixCompat.h
depends:              base-4.13.0.0 unix-2.7.2.2
haddock-interfaces:   /usr/share/doc/haskell-unix-compat/html/unix-compat.haddock
haddock-html:         /usr/share/doc/haskell-unix-compat/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unix-compat-0.5.2-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unix-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 unix-compat
version:              0.5.2
visibility:           public
id:                   unix-compat-0.5.2-7IcOHcLTxJI58jp45CNrGP
key:                  unix-compat-0.5.2-7IcOHcLTxJI58jp45CNrGP
license:              BSD-3-Clause
maintainer:           Jacob Stanley <jacob@stanley.io>
author:
    Björn Bringert, Duncan Coutts, Jacob Stanley, Bryan O'\''Sullivan

homepage:             http://github.com/jacobstanley/unix-compat
synopsis:             Portable POSIX-compatibility layer.
description:
    This package provides portable implementations of parts
    of the unix package. This package re-exports the unix
    package when available. When it isn'\''t available,
    portable implementations are used.

category:             System
abi:                  c1824b076b89c70a3d39705f0ffd77d6
exposed:              True
exposed-modules:
    System.PosixCompat System.PosixCompat.Extensions
    System.PosixCompat.Files System.PosixCompat.Temp
    System.PosixCompat.Time System.PosixCompat.Types
    System.PosixCompat.Unistd System.PosixCompat.User

import-dirs:          /usr/lib/ghc-8.10.2/site-local/unix-compat-0.5.2
library-dirs:         /usr/lib/ghc-8.10.2/site-local/unix-compat-0.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/unix-compat-0.5.2
hs-libraries:         HSunix-compat-0.5.2-7IcOHcLTxJI58jp45CNrGP
include-dirs:         /usr/lib/ghc-8.10.2/site-local/unix-compat-0.5.2/include
includes:             HsUnixCompat.h
depends:              base-4.14.1.0 unix-2.7.2.2
haddock-interfaces:   /usr/share/doc/haskell-unix-compat/html/unix-compat.haddock
haddock-html:         /usr/share/doc/haskell-unix-compat/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
